@@ -89,6 +89,12 @@
 #ifdef CLUTTER_INPUT_WAYLAND
 #include "wayland/clutter-device-manager-wayland.h"
 #endif
+#ifdef CLUTTER_WINDOWING_MIR
+#include "mir/clutter-backend-mir.h"
+#endif
+#ifdef CLUTTER_INPUT_MIR
+#include "mir/clutter-device-manager-mir.h"
+#endif
 
 #ifdef HAVE_CLUTTER_WAYLAND_COMPOSITOR
 #include <cogl/cogl-wayland-server.h>
@@ -510,6 +516,11 @@ _clutter_create_backend (void)
   if (backend == NULL || backend == I_(CLUTTER_WINDOWING_EGL))
     retval = g_object_new (CLUTTER_TYPE_BACKEND_EGL_NATIVE, NULL);
   else
+#endif
+#ifdef CLUTTER_WINDOWING_MIR
+  if (backend == NULL || backend == I_(CLUTTER_WINDOWING_MIR))
+    retval = g_object_new (CLUTTER_TYPE_BACKEND_MIR, NULL);
+  else
 #endif
   if (backend == NULL)
     g_error ("No default Clutter backend found.");
@@ -589,6 +600,14 @@ clutter_backend_real_init_events (ClutterBackend *backend)
       _clutter_events_wayland_init (backend);
     }
   else
+#endif
+#ifdef CLUTTER_INPUT_MIR
+  if (clutter_check_windowing_backend (CLUTTER_WINDOWING_MIR) &&
+      (input_backend == NULL || input_backend == I_(CLUTTER_INPUT_MIR)))
+    {
+      _clutter_events_mir_init (backend);
+    }
+  else
 #endif
   if (input_backend != NULL)
     {
