@@ -159,7 +159,9 @@ void                   clutter_gesture_action_cancel               (ClutterGestu
 CLUTTER_AVAILABLE_IN_1_18
 void                            clutter_gesture_action_set_threshold_trigger_edge       (ClutterGestureAction      *action,
                                                                                          ClutterGestureTriggerEdge  edge);
-CLUTTER_AVAILABLE_IN_1_18
+CLUTTER_DEPRECATED_IN_1_20_FOR(clutter_gesture_action_get_threshold_trigger_edge)
+ClutterGestureTriggerEdge       clutter_gesture_action_get_threshold_trigger_egde       (ClutterGestureAction      *action);
+CLUTTER_AVAILABLE_IN_1_20
 ClutterGestureTriggerEdge       clutter_gesture_action_get_threshold_trigger_edge       (ClutterGestureAction      *action);
 
 CLUTTER_AVAILABLE_IN_1_18
